summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/messagebox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/messagebox.h')
-rw-r--r--kalarm/lib/messagebox.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kalarm/lib/messagebox.h b/kalarm/lib/messagebox.h
index 7a84cf20..b0cae293 100644
--- a/kalarm/lib/messagebox.h
+++ b/kalarm/lib/messagebox.h
@@ -113,12 +113,12 @@ class MessageBox : public KMessageBox
* @param dontShow If true, the message box will be suppressed and will return Continue.
*/
static void saveDontShowAgainContinue(const TQString& dontShowAgainName, bool dontShow = true);
- /** Sets the KConfig object to be used by the MessageBox class. */
- static void setDontShowAskAgainConfig(KConfig* cfg) { mConfig = cfg; }
+ /** Sets the TDEConfig object to be used by the MessageBox class. */
+ static void setDontShowAskAgainConfig(TDEConfig* cfg) { mConfig = cfg; }
private:
static void saveDontShowAgain(const TQString& dontShowAgainName, bool yesno, bool dontShow, const char* yesnoResult = 0);
- static KConfig* mConfig;
+ static TDEConfig* mConfig;
static TQMap<TQString, ButtonCode> mContinueDefaults;
};